# Utah
* We don't have any code logic in FiscalSim-US for Utah exempt status as stated in line 21 of the 2022 Utah Individual Income Tax Return [form TC-40](https://tax.utah.gov/forms/current/tc-40.pdf). Page 2 of the [instructions for form TC-40](https://tax.utah.gov/forms/current/tc-40inst.pdf) describe "Qualified Exempt Taxpayer" and "Nonresident Filing Exemption".
* We don't have any code logic in FiscalSim-US for Utah Penalty and interest described in line 4 of the 2022 Utah Individual Income Tax Return [form TC-40](https://tax.utah.gov/forms/current/tc-40.pdf).
* We do not model full or part-year resident status in line 25 of the 2022 Utah Individual Income Tax Return [form TC-40](https://tax.utah.gov/forms/current/tc-40.pdf).
* We do not model voluntary contributions from TC-40 on page 3, part 4 in line 28 of the 2022 Utah Individual Income Tax Return [form TC-40](https://tax.utah.gov/forms/current/tc-40.pdf).
* We do not model previous refund for amended returns on line 29 of the 2022 Utah Individual Income Tax Return [form TC-40](https://tax.utah.gov/forms/current/tc-40.pdf).
* We do not model the Utah use tax from line 31 of the 2022 Utah Individual Income Tax Return [form TC-40](https://tax.utah.gov/forms/current/tc-40.pdf). This is a tax on goods and taxable services for use, storage, or other consumption in Utah during the taxable year and applies only if sales tax was not paid at the time of purchase. (see [TC-40 instructions](https://tax.utah.gov/forms/current/tc-40inst.pdf), pages 9-10). The Use Tax Worksheet is available in the TC-40 instructions along with the use tax rates in each Utah local unit.
